<form action="{% url "index" %}" method="GET">
    <input type='hidden' id='subform' name="subform" value='describe' />
    <select id='typeName' name='typeName'>
    {% for layer in layers %}
        <option value="{{ layer }}">{{ layer }}</option>
    {% endfor %}
    </select>
    <input type='submit' value='Describe' />
</form>

<form action="{% url "index" %}" method="GET">
    {% csrf_token %}
    <input type='hidden' id='subform' name="subform" value='download' />
    <select id='typeName' name='typeName'>
    {% for layer in layers %}
        <option value="{{ layer }}">{{ layer }}</option>
    {% endfor %}
    </select>
    <input type="submit" value="Download" />
</form>

<!-- Upload form. Note enctype attribute! -->
<form action="{% url "index" %}" method="POST" enctype="multipart/form-data">
    {% csrf_token %}
    <p>{{ file_upload_form.non_field_errors }}</p>
    <p>select xsd to upload: </p>
    <p>{{ file_upload_form.docfile.errors }} </p>
    <p>    {{ file_upload_form.docfile }} </p>
    <input type='hidden' id='subform' name="subform" value='upload' />
    <select id='typeName' name='typeName'>
    {% for layer in layers %}
        <option value="{{ layer }}">{{ layer }}</option>
    {% endfor %}
    </select>
    <input type="submit" value="Upload" />
</form>